package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````@!<``#0```",D0````(`!30`(``)
M`"@`&P`:``$``'#(C```R(P``,B,```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````#4C```U(P```4`````$```
M`0```+R-``"\G0``O)T``(P"``"@`@``!@`````0```"````Q(T``,2=``#$
MG0``"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO(T`
M`+R=``"\G0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`)V0C<419GW<794>XU!(G^N#J+10!````!`````!
M````1TY5```````#`````@`````````1````2P````@````(`````9`0!"5`
M!(`H@``%H(90A("!``(+*`2,.(`208H```A+````3````$\```!3````5```
M`%T```!>````7P````````!A````8@```&,```!D````90```&@`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"R`8MOF4_#FVL)0]9GK\QF0D75[(D'
M<-,S8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[20``````````````
M````````````O!$````````#``L```````"@`````````P`6``0"````````
M`````!(```!W`@`````````````2````90(`````````````$@```-8"````
M`````````!(```"5`@`````````````B````_`(`````````````$0```(,#
M`````````````!(````0```````````````@````_P$`````````````$@``
M`,$"`````````````!(```#C`0`````````````2````Z0``````````````
M$@```!@#`````````````!$```#/`@`````````````2````30$`````````
M````$@```/D!`````````````!(```"'```````````````2````JP(`````
M````````$@```.0``````````````!(```"]`0`````````````2````E0$`
M````````````$@````8#`````````````!(```#<`0`````````````2````
M00(`````````````$@```#\!`````````````!(```#&```````````````1
M````#0$`````````````$@```&,``````````````!8````X`@``````````
M```2````AP(`````````````$0```'L!`````````````!(```"K`0``````
M```````2````:`$`````````````$@```+D"`````````````!(```#-`0``
M```````````2````=`$`````````````$@```!$"`````````````!(````;
M`0`````````````2`````0``````````````(````"`"`````````````!(`
M``"F`0`````````````2````\@$`````````````$@```(8!````````````
M`!$```!4```````````````2````I`(`````````````$@```)8`````````
M`````!(```#=`@`````````````2````20(`````````````$@```*(`````
M`````````!(````T`0`````````````2````"P(`````````````$@```+("
M`````````````!(```#Z```````````````2````1@``````````````$@``
M`.X``````````````!(```!=`0`````````````2````5P(`````````````
M$@```-,``````````````!(```".`@`````````````2````R`(`````````
M````$@```.L!`````````````!(````G`@`````````````2````=@``````
M````````$@```-0!`````````````!(```"S`0`````````````2````MP``
M````````````$@```"L!`````````````!(````L```````````````@````
M_@(`````````````$0```/0"`````````````!(```#N`@`````````````2
M````Q`$`````````````$@```*`#``!<H````````!``%P",`P``J#D``#P!
M```2``T`Q`,``,0O``#T!@``$@`-`'("``"P%```T`(``!(`#0!2`P``I"$`
M``0````2``T`8P,``$B@````````$``7`%`$``"H(0``D`(``!(`#0".!```
MN#8``/`"```2``T`/`0``$B@````````$``7`*L#```X)```,````!(`#0#1
M`P``$$@``"@!```2``T`Z0,``-1*```$````$0`/`!@$``!<H````````!``
M%P`=!```7*`````````0`!<`2`0``#0@``!<````$@`-`%T$``!4+@``<`$`
M`!(`#0!O!```5"L``*`````2``T`?00``/0K``!T````$@`-`-P#````H```
M`````!``%@"X`P``:"0``*@!```2``T`F`,``$B@````````$``6``X$``!$
MH```!````!$`%@#B`P``@!<````````2``T`A00``'A'``"8````$@`-`-X#
M````H````````"``%@!Q`P``,"X``"0````2``T`GP,``%R@````````$``7
M`/@#``"0(```%`$``!(`#0`R!```.$D``&P!```2``T`)00``!`F``!$!0``
M$@`-``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W
M<F%P`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S
M=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`
M<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`'-T<G-T<@!M:V1I<@!?7W9F<')I
M;G1F7V-H:P!G971P:60`7U]L<W1A=#8T7W1I;64V-`!R96%D;&EN:P!R96%L
M;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!?7VQI8F-?<W1A<G1?
M;6%I;@!?7W-T870V-%]T:6UE-C0`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA
M;&EZ90!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E
M<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC
M;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U
M87)D`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`;&0M;&EN=7@N<V\N,P!P
M87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T
M90!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`'-H
M85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'!A<E]D:64`<VAA7VEN:70`
M6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-`!'3$E"0U\R+C,T````
M```````"``,``P`"``(``@`"``$``@`"``(``@`$``(``0`"``$``@`!``(`
M`@`"``(``@`!``$``0`!``(``@`!``(``0`"``(``@`"``$``0`"``(``@`!
M``$``@`!``(``@`!``$``@`"``$``0`!``$``@`!``(``@`"``,``0`"``(`
M`0`!``$``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`1`,``!`````@````
M%&EI#0``!`"D!`````````$``@`Z`P``$`````````"TD98&```#`*X$```0
M````%&EI#0```@"D!````````+R=```7````P)T``!<```#PGP``%P````2@
M```7````%*```!<````8H```%P```""@```7````)*```!<````HH```%P``
M`"R@```7````,*```!<````XH```%P```#R@```7````1*```!<```#(GP``
M%0<``,R?```5"@``T)\``!4/``#4GP``%1$``-B?```5'```W)\``!,>``#@
MGP``%2```.2?```5*0``Z)\``!4M``#LGP``%3<``/2?```500``^)\``!5&
M``#\GP``%4<``-B>```6`P``W)X``!8$``#@G@``%@4``.2>```6!@``Z)X`
M`!8'``#LG@``%@D``/">```6"P``])X``!8,``#XG@``%@T``/R>```6#@``
M`)\``!80```$GP``%A(```B?```6$P``#)\``!84```0GP``%A4``!2?```6
M%@``&)\``!87```<GP``%A@``""?```6&0``))\``!8:```HGP``%AL``"R?
M```6'0``,)\``!8?```TGP``%B$``#B?```6(@``/)\``!8C``!`GP``%B0`
M`$2?```6)0``2)\``!8F``!,GP``%B<``%"?```6*```5)\``!8I``!8GP``
M%BH``%R?```6*P``8)\``!8L``!DGP``%BX``&B?```6+P``;)\``!8P``!P
MGP``%C$``'2?```6,@``>)\``!8S``!\GP``%C0``("?```6-0``A)\``!8V
M``"(GP``%C@``(R?```6.0``D)\``!8Z``"4GP``%CL``)B?```6/```G)\`
M`!8]``"@GP``%CX``*2?```6/P``J)\``!9```"LGP``%D(``+"?```60P``
MM)\``!9$``"XGP``%D4``+R?```62```P)\``!9)``#$GP``%DH```A`+>E_
M`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7TC````,:/X@C*C.+T_+SE`,:/X@C*
MC.+L_+SE`,:/X@C*C.+D_+SE`,:/X@C*C.+<_+SE`,:/X@C*C.+4_+SE`,:/
MX@C*C.+,_+SE`,:/X@C*C.+$_+SE`,:/X@C*C.*\_+SE`,:/X@C*C.*T_+SE
M`,:/X@C*C.*L_+SE`,:/X@C*C.*D_+SE`,:/X@C*C.*<_+SE`,:/X@C*C.*4
M_+SE`,:/X@C*C.*,_+SE`,:/X@C*C.*$_+SE`,:/X@C*C.)\_+SE`,:/X@C*
MC.)T_+SE`,:/X@C*C.)L_+SE`,:/X@C*C.)D_+SE`,:/X@C*C.)<_+SE`,:/
MX@C*C.)4_+SE`,:/X@C*C.),_+SE`,:/X@C*C.)$_+SE`,:/X@C*C.(\_+SE
M`,:/X@C*C.(T_+SE`,:/X@C*C.(L_+SE`,:/X@C*C.(D_+SE`,:/X@C*C.(<
M_+SE`,:/X@C*C.(4_+SE`,:/X@C*C.(,_+SE`,:/X@C*C.($_+SE`,:/X@C*
MC.+\^[SE`,:/X@C*C.+T^[SE`,:/X@C*C.+L^[SE`,:/X@C*C.+D^[SE`,:/
MX@C*C.+<^[SE`,:/X@C*C.+4^[SE`,:/X@C*C.+,^[SE`,:/X@C*C.+$^[SE
M`,:/X@C*C.*\^[SE`,:/X@C*C.*T^[SE`,:/X@C*C.*L^[SE`,:/X@C*C.*D
M^[SE`,:/X@C*C.*<^[SE`,:/X@C*C.*4^[SE`,:/X@C*C.*,^[SE`,:/X@C*
MC.*$^[SE`,:/X@C*C.)\^[SE`,:/X@C*C.)T^[SE`,:/X@C*C.)L^[SE`,:/
MX@C*C.)D^[SE`,:/X@C*C.)<^[SE`,:/X@C*C.)4^[SE`,:/X@C*C.),^[SE
M`,:/X@C*C.)$^[SE`,:/X@C*C.(\^[SE`,:/X@C*C.(T^[SE`,:/X@C*C.(L
M^[SE`,:/X@C*C.(D^[SE`,:/X@C*C.(<^[SE``````'*H.-P0"WI#,!-X,@/
MC.5@PI_E8#*?Y2C03>(,P(_@'`"-Y1@0C>44((WE`S"<YQ@0C>(4((WB'`"-
MXCQ"G^4`,)/E)#"-Y0`PH..?___K+"*?Y01`C^`H,I_E`B"4YPP@C>4#,)3G
M`A"@X0,`H.$0,(WE8PT`ZPPRG^4#,)3G`%#3Y0``5>-1```*_#&?Y5H-`.L#
M,)_G'%"=Y0,@D.<$`(7BUC/2Y0<!<.,#,(/C`U"%XM8SPN5B``"*``&@X63_
M_^O($9_ER"&?Y0$0C^`"((_@`,"1Y1Q`G>48$)WE`0!4XP#@D>4`,*#A!`""
MY:0!G^6D(9_E``"/X`(@C^``X(/E`1"#Z0P@@^54``#:!`!!X@S`@^($`8#@
M!."QY03@K.4!`%#A^___&@-`A.(`$*#C:&&?Y0`0C>4$$8/G8!&?Y09@C^`,
M`);E!2"@X0$0C^!^___K``!0XRD```I$49_E(&"-X@50C^`,`)7E*?__ZP80
MH.$`0*#A+`&?Y0``C^"K``#K``!0XR````H<,9_E`S"/X`P`D^4,___K9?__
MZPPAG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB
M<("]Z!G__^O<()_E`B"/X```4.,,`(+E'P``"O+^_^O(,)_E`0T`ZP,PG^<#
M,)#GOE;#Y:#__^H,`);E;O__Z]+__^H(`)7E``!0XP$```JT"`#KV?__ZI0`
MG^4&$*#A``"/X'\``.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)3G``"/
MX`,0H.$,,(WE*?__ZP1`H..P___J`0"@XQ#__^O<_O_K^(D```0!``#`B0``
M(`$``"@!```,`0``D(H``,"*``#$B@``U#@``-0X``!0B@``?`D``"R*``#T
M-0```(H``&B(``"XB0``+(D``.`T```<`0``N#8```"PH.,`X*#C!!"=Y`T@
MH.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN>._O_K-?__
MZQ"'```D`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!V_[_ZOB&```8`0``
M+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>
M_R\!$_\OX5"(``!,B```Q(8````!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?
MH.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A#(@`
M``B(``!TA@``+`$``$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E
M$$`MZ0,PDN<``%/C`@``"B@PG^4#`)_G5/[_Z\K__^L<,)_E`2"@XP,PC^``
M(,/E$("]Z+R'```XA@``_````$R'``!\AP``T/__Z@'*H./P1RWI#,!-X.`/
MC.7(,)_E`(!0X@,PC^`K```*O""?Y0(PD^<`D)/E``!9XR@```H`4-CE`7"@
MX0``5>,]`%43`5"@$P!0H`,1```:`$"9Y0``5.,,```*"6"@X04@H.$($*#A
M!`"@X<O^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'P
MA[WH"%"@X0$P]>4``%/C/0!3$_O__QH(4$7@YO__Z@E@1N`!4(7B1F&@X05`
MA.`$`*#A`&"'Y?"'O>@(0*#A[?__Z@E`H.'K___JQ(4``#`!```!RJ#C$$`M
MZ0S`3>"`#XSEC""?Y8PPG^4"((_@>-!-X@,PDN<-$*#A`$"@X0`PD^5T,(WE
M`#"@XX_^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`
M,)_E`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C!P``&GC0C>(0@+WH`A"@XP0`
MH.%S_O_K$`]OX:`"H.'N___J"?[_Z]R$```$`0``D(0```'*H./P0"WI#,!-
MX&@/C.5<(9_E7#&?Y0(@C^`#,)+GA-!-X@!@4.(`,)/E?#"-Y0`PH.,"```*
M`##6Y0``4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^5\,)WE`B`SX``PH.-!
M```:A-"-XO"`O>@'_O_K`$!0XO'__PH$`*#A5_[_ZP``4.,J```*$S#0Y1-0
M@.(N`%/C`@``&@$PU>4``%/C]/__"A,PT.4N`%/C)0``"@8`H.$-_O_K`'"@
MX04`H.$*_O_K``"'X`(`@.+U_?_KI#"?Y0`@X.,#,(_@`1"@XP10C>4`8(WE
M`'"@X0[^_^L($(WB!P"@X9G]_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2
M```*Q/W_ZP<`H.&G_?_K!`"@X2S^_^L``%#CU/__&@0`H.$W_O_K!@"@X:7]
M_^N]___J`3#5Y2X`4^/6__\:`C#5Y0``4^/%__\*TO__ZJ3__^OK___JJ?W_
MZRR$```$`0``^(,```0P```!RJ#C\$<MZ0S`3>#8#XSE`##1Y1`BG^4]`%/C
M##*?Y0(@C^`!0*#A`S"2YP%`@0((T$WB`%"@X00`H.$`,)/E!#"-Y0`PH./(
M_?_K#1"@X=R!G^4(@(_@`&"@X04`H.$?___K`)!0XD````J__?_K``!6X3<`
M`)JX,9_E`'"=Y0.`F.<'<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@
MX0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)CEE_W_ZP``4.,'`(;G
M%0``"@`@F.4%`*#A`3#0Y`<0DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"
M$*#A/0!3XP``4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0!,.+E``!3X_O_
M_QH((9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]
MZ`&02>(!,-3D`3#IY0``4^/[__\:[O__ZL`PG^4#@)CG`'"8Y0`PE^4``%/C
M)```"@<PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!$:#AD#"?Y0,PC^``
M()/E``!2XP\``!H!(*#C`0"@X0`@@^56_?_K`*!0XM7__PH'$*#A"7&@X0<@
MH.$4_?_K`*"(Y0`PH.,`D(WE`9")X@DQBN>B___J!P"@X2W]_^L``%#C`*"@
MX0``B.7%__\*"7&@X?+__^H#D*#A"!"@X]___^H:_?_KH((```0!``!L@@``
M,`$``(R!``"4@@```<J@X_!!+>D,P$W@``",Y2``#.4!<*#A`!&?Y0`QG^4!
MVDWB"-!-X@$0C^`#,)'G`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`
MC>+4()_E``"/X`@0H.$._?_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2
MXQ<``!H``%/C%```&J`PG^7U"@#K`S"?YP<@H.$#`)#G!A"@X?K\_^N(()_E
M=#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((
MT(WB\(&]Z`-`H.$$(*#A+Q"@XP@`H.$[_?_K``!0X^/__PHX,)_EV0H`ZP,P
MG^<((*#A`P"0YP80H.$$,*#A0_W_Z^'__^K,_/_K5(````0!``#,+```_P\`
M`/R```#0?P``C(````'*H.,00"WI#,!-X.@/C.5T$)_E=#"?Y0$0C^!P()_E
M$-!-X@,PD><,,(WE`B"?YV`PG^5@$)_ENPH`ZP,PC^``0*#A`1"/X`(`D.<,
M()WE^_S_ZT0`G^5$,)_E``"?YT`@G^5`$)_E`S"/X`#`H.,``)3G`B"/X`$0
MC^`($(WH!/W_ZQ#0C>(0@+WH*'\```@!```D@```7&P``+`K``#T?P``C"X`
M`+@6``"8*P``$$`MZ9P*`.LX0)_E.""?Y01`C^`T,)_E"-!-X@(@E.<$((WE
M`S"?YR00G^4#`)#G(#"?Y0$0C^`#,(_@"-"-XA!`O>C2_/_J@'X```@!``!\
M?P``$"L``+!K```!RJ#C<$`MZ0S`3>```(SE`<I,X@``C.4H``SEV""?Y=@P
MG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..?_/_KL,"?
MY;`PG^4,P(_@#$"-X@%JC>*D()_E`S"/X`$0H.,08(;B`1"-Z`0`H.&H_/_K
M!`"@X0$JH.,&$*#A<?S_ZP!`4.(`4*"S"```N@$`A.)^_/_K`%!0X@0```H$
M(*#A!A"@X4/\_^L`,*#C!##%YTP@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@
MD^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(8T(WB<("]Z$/\_^L(?@``!`$`
M`-0J``"X*@```1```'!]``"Y___J`<J@X_!/+>D,P$W@``",Y;``#.5$(I_E
M1#*?Y4+=3>(,T$WB`B"/X`!@H.$T`I_E`S"2YT+-C>(0@(WB`4"@X0``C^`(
M$*#A!,",X@`PD^4`,(SE`#"@X[C]_^LO$*#C`%"@X08`H.%=_/_K``!0XQ(`
M``KP`9_E!A"@X0``C^!U_O_K!@"@X>`AG^70,9_E`B"/X$(=C>(#,)+G!!"!
MX@`@D^4`,)'E`B`SX``PH.-I```:0MV-X@S0C>+PC[WH!`"@X0?\_^ND$9_E
M`1"/X'#\_^L`0%#BY?__"@`PU.60D9_EB*"-X@``4^,)D(_@!'!*XCL```H`
M`%7C!```"@00H.$%`*#ATOO_ZP``4.,K```*!`"@X2O\_^L!,$#B`S"$X`,`
M5.$`L*#A`#"$,``0H#,!`(0R`P``.@@``.H#`%#A`!##Y0(```H!('/E+P!2
MX_G__PH$`*#A&OS_ZP"PH.$&`*#A%_S_ZPL`@.`!`(#B`0I0X[W__RKX`)_E
M"3"@X0``C^`!*J#C`1"@XT$`C>D`0(WE!P"@X1G\_^L($*#A!P"@X:3[_^L`
M`%#C`P``&F@P&N4/.@/B`@E3XQ4```JT$)_E``"@XP$0C^`P_/_K`$!0XJ7_
M_PH`,-3E``!3X\/__QH``%7C%@``"@`PU>4N`%/C`P``"H!`G^4!L*#C!$"/
MX-7__^H!,-7E``!3X^K__PKW___J`1"@XP<`H.$8_/_K``!0X^3__QI0`)_E
M!Q"@X0``C^`&_O_K!P"@X:?[_^N.___J.$"?Y0&PH.,$0(_@P?__ZJ3[_^OX
M?```!`$``-@I``"H*0``C'P``&@I``!,*0``O"@``&@H```0*```["<``,`G
M```!RJ#C$$`MZ0S`3>#X#XSE+Q"@XP!`H.$`_/_K``!0XP%`@!($`*#A$$"]
MZ(G[_^H!RJ#C<$`MZ0S`3>```(SE&``,Y7`AG^5P,9_E`=I-X@(@C^`(T$WB
M`1J-X@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@XR\```H`,-;E``!3XRP```JL
M^__K`2"`X@$*4N,`0*#A.```B@10C>(&$*#A!0"@X5S[_^L!,$3B`S"%X`4`
M4^$'``":`!"@XP(``.H%`%/A`1##Y0(```H!(%/D+P!2X_G__PHO$*#C!0"@
MX<[[_^L``%#C)0``"@4`4.$`,*"#`##`A04`H.%5^__KO""?Y;0PG^4"((_@
M`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(
M()_E?#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C%```&F``
MG^4``(_@`=J-X@C0C>)P0+WH-OO_Z@``H./>___J1""?Y3`PG^4"((_@`1J-
MX@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR``GP4``(\`[/__"BG[_^L\>@``
M!`$``(1Y``!,>0``'"8```!Y``#4)0```<J@XW!`+>D,P$W@Z`^,Y<0DG^7$
M-)_E`B"/X,!DG^4#,)+G"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50
MC^`$$*#A!@"@X:'\_^L``%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3
MY0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@
M!!"@X08`H.&+_/_K``!0XPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`
M(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00
MH.$&`*#A=?S_ZP``4.,.```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!
MYP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A
M!@"@X5_\_^L``%#C#@``"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><`
M`%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`
MH.%)_/_K``!0XPX```HL,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2
MX_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A
M,_S_ZP``4.,.```*U#*?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q
M__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X1W\
M_^L``%#C#@``"GPRG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__
M"@0P@^($()/E!""#Y```4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.$'_/_K
M``!0XPX```HD,I_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$
M,(/B!""3Y00@@^0``%+C^___&NO__^H(8I_E!F"/X`00H.$&`*#A\?O_ZP``
M4.,.```*S#&?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#
MX@0@D^4$((/D``!2X_O__QKK___JM&&?Y09@C^`$$*#A!@"@X=O[_^L``%#C
M#@``"G0QG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($
M()/E!""#Y```4N/[__\:Z___ZF!AG^4&8(_@!!"@X08`H.'%^__K``!0XPX`
M``H<,9_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3
MY00@@^0``%+C^___&NO__^H,`9_E!!"@X0``C^"P^__K`!!0X@(```KX`)_E
M``"/X'+\_^OP`)_E!!"@X0``C^"G^__K`!!0X@(```K<`)_E``"/X&G\_^O4
M`)_E!!"@X0``C^">^__K`!!0XA(```K``)_E``"/X&#\_^NX()_E9#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-
MXG!`O>A0_/_JA`"?Y000H.$``(_@A?O_ZP`04.+I__\*<`"?Y0``C^!'_/_K
MY?__ZNOY_^N<>```!`$``+`E``!T>```,`$``%`E````)0``M"0``&0D```<
M)```8",``'@C```L(P``X"(```PB```X(@``#"(``"@B```H(@``)"(``$@A
M```\=```9",``&0A``#0(0``5"$```'*H.,$X"WE#,!-X/`/C.5X()_E>#"?
MY0(@C^!T`)_E#-!-X@,PDN<``(_@#1"@X0`PD^4$,(WE`#"@XU3[_^L``%#C
M!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,PDN<`
M()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WDK?G_ZUAS```$`0``M"````AS
M```!RJ#C#P`MZ03@+>4,P$W@\`^,Y4@`G^5($)_E``"/X`$0D.=`P)_E#-!-
MXCP@G^4,P(_@`!"1Y000C>4`$*#C%#"-X@`PC>4"$)SG$""=Y0``D>4!$*#C
MN?G_Z_\`H./#^?_KM'(```0!``"@<@``%`$```#`H./P1RWI`>B@XPS`3>`.
MX$S@`<I,X@``C.4.`%SA^___&C@`#N4!V$WB&-!-X@(0H.-PP9_E`!"-Y6P1
MG^4,P(_@`1"<YP'HC>(`(*#C`#"@XP`0D>44$([E`!"@XQ3@CN(`@*#AB?G_
MZP%@4.(`<,'BQR^@X<<_)N`",%/@`SB@X2,XH.$","/@`C!3X`(@PN`#8%;@
M`G#'X```5^,W``"Z")&?Y0Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-Y7/Y_^L!
M`''C`0!P`S(```H)(*#A!1"@X0@`H.$V^?_K`0!PXRD```H'`%#C'P``F@@`
M0.(`0)7@'```*K2@G^4*H(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@
MX3KY_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(C>(#,)+G
M%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!
M`'?C`0AV`\G__QH``.#C`!"@X>G__^HH`)_E``"/X'O__^L@`)_E``"/X'C_
M_^LA^?_K''(```0!```(``$`F'(``!QQ``#`'@``I!X```'*H.,00"WI#,!-
MX/@/C.7Z^/_K\_C_ZP``4.,``)`5$("]Z`'*H./P0"WI#,!-X-`/C.4T(9_E
M-&&?Y30QG^4"((_@'-!-X@,PDN<&8(_@`%"@X1`0C>(&`*#A`#"3Y10PC>4`
M,*#CDOK_ZP!`4.("```*`##4Y0``4^,.```:]""?Y>PPG^4"((_@`S"2YP`@
MD^44,)WE`B`SX``PH.,Q```:U`"?Y040H.$``(_@'-"-XO!`O>A%^__J!1"@
MX;GX_^L``%#C"@``"K`@G^6@,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C
M'@``&AS0C>+P@+WH!0"@X1#Y_^L`<*#A!`"@X0WY_^L``(?@`@"`XOCX_^MH
M,)_E`"#@XP,PC^`8`(WI7#"?Y0$0H.,#,(_@`%"-Y0!PH.$/^?_K2""?Y2PP
MG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,'$*`!!@"@`=#__PJ^^/_K5'``
M`$P>```$`0``#'```.P=``#`;P``C!P``(`<``!,;P```<J@X_!/+>D,P$W@
MX`Z,Y5#&G^4`H*#A#,"/X`PPC.('`)/H_-!-XI!PC>('`(?H-":?Y30VG^4"
M((_@`S"2YQA@C.(`,)/E]#"-Y0`PH.,/`+;HJ$"-X@3@H.$/`*[H`P"6Z##`
MC.(#`([H!P"<Z)Q0C>('`(7H]`6?Y2"`C>(``(_@"!"@X27Z_^ODM9_E"["/
MX`!@4.("```*`##6Y0``4^,8`0`:;_C_ZVCX_^L``%#C>@``"@!@D.4``%;C
M=P``"@8`H.&X^/_K@`"@X0$`@.*C^/_K`!#6Y0``4>,`4*#A'`"-Y0L```J(
ME9_E"9"/X`4`H.$`$(WE"3"@X0$0H.,`(.#CM_C_ZP$0]N4"4(7B``!1X_7_
M_QI<!9_E``"/X`(``.H$`+3E``!0XPT```H($*#A^?G_ZP!04.+X__\*`##5
MY0``4^/U__\*+?K_ZP``4./R__\*!0"@X5GX_^L`0%#B#0``&@1`E^0``%3C
M"@``"@`PU.4``%/CT```"@0`H.$?^O_K``!0X_7__PH$`*#A2_C_ZP!`4.+Q
M__\*!`"@X8#X_^L<8)WE`'"@X08`H.%\^/_K`'"'X`%[A^($<(?B!P"@X67X
M_^NL-)_E`"#@XP,PC^`(,(WEH#2?Y0$0H.,#,(_@!#"-Y90TG^4,8(WE`S"/
MX`!`C>4`4*#A>/C_ZP<=H.,%`*#A?OC_ZP$`<.,#```:;_C_ZP`0D.41`%'C
MK```&@@0H.$%`*#AD_C_ZP!@4.(M```*2"2?Y0`PFN4"$)OG0"2?Y0``D>4"
M((_@`1"@XP!0C>5Y^/_K`'"@XR@DG^7\,Y_E`B"/X`,PDN<`()/E]#"=Y0(@
M,^``,*#C\@``&@<`H.'\T(WB\(^]Z`OX_^L`8%#BB@``&@0`E>0``%#C"0``
M"@@0H.&:^?_K`#!0XOC__PH`,-/E``!3X_+__QH$`)7D``!0X_7__QH-`*#C
M(?C_Z[1CG^53$*#C!F"/X`!0H.$<`(WE?/__ZC`PG>4/.@/B`0E3X\W__QHX
M0)WEUO?_ZP``5.')__\:,#"=Y8,[H.&C.Z#A!PU3X\3__QH'`*#A#/C_ZP@0
MH.$`<*#A7`.?Y0``C^!V^?_K`!!0XGP```H``)KEHOO_ZP"04.)X```*"0"@
MX1'X_^L#`%#C`$"@X0P``)HH$Y_E!`!`X@``B>`!$(_@K/?_ZP``4.,%```:
M!`!4XZ````H$0(G@!3!4Y2\`4^.<```*^`*?Y0@0H.$``(_@6OG_ZP``4.,#
M```*`##0Y3``4^,``%,3!```&@`0H.,)`*#AW_?_ZP!`4.)9```:P!*?Y<`"
MG^4!$(_@``"/X!'Z_^OF]__KL#*?Y;`BG^4#,(_@##"-Y:@RG^4"((_@I**?
MY:22G^6D@I_E!""-Y0,PC^``(.#C`1"@XP!0C>4*H(_@"9"/X`B`C^`(`(WE
M!P"@X>?W_^L.``#JXO?_ZP`PD.41`%/C$```&LSW_^L!$*#C`6"&X`HPH.$$
M(*#A$)"-Y0Q@C>4`P*#A(!&-Z`<`H.'7]__K!QV@XP<`H.'=]__K`0!PXP!`
MH.'J__\*!0"@X77W_^L8`I_E!Q"@X0``C^#@^?_K!P"@X7+^_^MG___J`T"@
MX33__^JV]__K@`"@X0$`@.+\_O_JJ"&?Y0`PFN4"`)OGW"&?Y0``D.4"((_@
M!!"-Y0!0C>4!$*#CT/?_ZU7__^I?_O_KO"&?Y50QG^4"((_@`S"2YP`@D^7T
M,)WE`B`SX``PH.-(```:!@"@X?S0C>+P3[WH8??_Z@"0FN6$___JU/W_ZP"0
M4>(`@*#AH?__N@H@4.(`H*#C`##)X@0`H.'`L(WB`*"-Y6_W_^L&(*#C"Q"@
MX00`H.$U]__K!@!0XS(``!I`,9_EP""=Y0,`4N&0__\:M"#;X3`QG^4#`%+A
MC/__&C(@6.(`,,GB!`"@X<A@C>(`H(WE6_?_ZR@@H.,$`*#A!A"@X2'W_^LH
M`%#C'@``&O@PG^4`(.#C`S"/X`PPC>7L,)_E`1"@XP,PC^!(`(WIX#"?Y0<`
MH.$#,(_@`%"-Y?"@S>5T]__KH?__Z@1`FN4``%3C7___"@0`H.%?]__K`P!0
MXUO__YJL$)_E!`!`X@``A.`!$(_@^_;_ZP``4.,$D*`!4___ZA[W_^N,`)_E
M``"/X'']_^LD<```R&X```0!``!\&P``<&X``"P<``"8&P``6!L``#P:```L
M&P``%`$``"`;``"0;```+!H``(@:``!0&@``O!@``&`:``!\&```L!H``!08
M``#8&0``V!D``'P:``#H%P``2!<``$08``#H:0```$-!0TA%``#,&```+!8`
M`.07``"4%P``@!<```'*H.-P0"WI#,!-X.@/C.5X$I_E>"*?Y0$0C^`"()'G
M"-!-XFPRG^4`()+E!""-Y0`@H.,#,)_G[@0`ZP-`D.=4`I_E:##4Y0U0H.$`
M`(_@:3#$Y040H.%T^/_K``!0XP(```H`,-#E,0!3XVT```JX^__K)#*?Y=X$
M`.L#,)_G`T"0YQ@2G^4$`*#A`1"/X`,PH.,!(*#C^_;_ZP!`4.(.```*$""4
MY?@QG^4`$)+E`S"?Y_`AG^7.!`#K`B"/X`!@H.$#`)#GU/;_ZQ`PE.4`$)/E
M"#"1Y0$%$^-=```:R#&?Y<@1G^4#,)_GP00`ZP$@H.,`8*#A`1"/X`,`D.<#
M,*#CX/;_ZP!`4.(+```*H`&?Y040H.$``(_@0_C_ZP`@4.)#```*C#&?Y1`0
ME.4#,)_G`!"1Y0,`EN>W]O_K>#&?Y:L$`.L#,)_G<!&?Y0-@D.<`0*#A`1"/
MX`$@H.,&`*#AW?;_ZU@AG^4"((_@`!"@X08`H.&H]O_K2#&?Y4@!G^4#,)_G
M`""@XP,PE.<%$*#A``"/X&D@P^4C^/_K+%&?Y050C^```%#C`$"@X0@`A>42
M```*!QV@XP0`H.'5]O_K`2"`XA$`4.,!`%(3`#"@X24``(KX()_EL#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>6__?_K``!0
MXP!`H.$(`(7EYO__&K@`G^4``(_@MO;_ZP$PT.4``%/CD___"HW__^J@,)_E
M$""4Y0,PC^`$,)/E``"2Y0`0D^5.^?_KN?__ZH0PG^4#,)_G`P"6Y[7V_^N<
M___J7/;_ZW`@G^5P`)_E`B"/X`0@DN4``(_@`!"2Y00@H.&<]O_K]&<```0!
M``#H:```$!4``*!H``"@%@``;&@``'06```T:```0!8``/P3``#L9P``U&<`
M`.05``#H%0``F&<``'03``#H9P``+&8``#P5``!,9P``P&8``!1G````%0``
M`<J@XS!`+>D,P$W@Z`^,Y0PAG^4,,9_E`B"/X`!`H.$$`9_E`S"2YPS03>(-
M$*#A``"/X``PD^4$,(WE`#"@X[[W_^L`,%#B"@``"@`PT^4``%/C,`!3$P$P
MH`,`,*`3`3`CX@``5.,`,*`#`3`#$@``4^,*```:L""?Y:0PG^4"((_@`S"2
MYP`@D^4$,)WE`B`SX``PH.,@```:#-"-XC"`O>@`,-3E``!3X_'__PH$`*#A
M@?K_ZR\0H.,`4*#A>O;_ZP``4.,!4(`2!0"@X03V_^M8$)_E!""@XP$0C^!^
M]O_K``!0X^+__QI$()_E,#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XP,`
M`!H$`*#A#-"-XC!`O>CM]__J\_7_ZP1E```$`0``6!(``)QD``!P$@``*&0`
M```````!RJ#C\$\MZ0S`3>!`#8SE7.R?Y5P\G^4.X(_@I]]-X@,PGN<0((WB
M`!"@X4#`@.*`4(#B`#"3Y90RC>4`,*#C`@"@X0!`H.,$8!SE"'`<Y28TH.%G
MZ"?@_SP#XB8\@^$NY*#A!H2@X08\@^'_[,[C_V@(X@C`C.)GY"[@!C"#X04`
M7.$`X(#E!$"`Y0@P@.4,0(#E$`"`XNK__QJ"/X+B!#"-Y8@PG>48X(WB'*"=
MY0@0C>5X@)WE?""=Y1BPG>6`<)WEA&"=Y8S`G>404)WE%$"=Y0X`H.$#$*#A
M#."-Y0"@C>4!``#J";"@X0`PC>4!,*#A/."0Y3@0D.4(D+#E`*"@XPD0(>`(
M$"'@!X"@X0-PH.$$,)#E!1`AX`/@+N`"X"[@!.`NX`8@H.$,8*#AH<^@X8[`
MC.$!$)'@#!"!X03`G>4`0)WE``!<X0M0H.$*P*#A=*"`Y7`0@.7A__\:"!"=
MY0S@G>4`@)'E"#N?Y0$(D>D((![E($"1Y:AMH.$0<)'E&)"1Y0,@DN"`8H;A
M!""2X(ABAN$,P)'E`F"6X`D@)^`K4:#A"R`"X`D@(N`,7X7A`F"6X`M?A>$8
M()WE*,&@X0#/C.$%`"?@`R"2X`@``.`)()+@!P`@X`C/C.$``)+@""">Y0Q`
M)>`#()+@!D`$X`5`).`'()+@Y@V`X`0@DN#@38+@$"">Y0,@DN`%()+@9E$L
MX`!0!>`,4"7@!2"2X!A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@
M!<"<X.)=C.`@P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@*&">Y6(AH.$#
M8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X#``GN4#`)#@9`&`X&5!
M(N`,0`3@`D`DX`0`D.`X0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E023@Y@V`
MX`0@DN#@38+@0"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X$A0GN5@`:#A
M`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C.!0P)[E`\"<X&;!C.!D
M82#@`F`&X`!@)N`&P)S@6&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-
MC.`&`)#@[&V`X&``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.!H0)[E;,&@
MX0-`E.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@38+@<"">Y0,@DN!E(8+@
M9E$LX`!0!>`,4"7@!2"2X'A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D
M+8+@!<"<X.)=C."`P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@Y6V,X(C`
MGN5B(:#A`\"<X```G.!DP2+@!<`,X&3!+.`,`)#@YLV`X)``GN4#,)#@90$B
MX`8``.`"`"#@9#&#X``PD^#LK8/@F`">Y2PXG^5F8:#A`P"0X*!`GN4"()#@
M90$FX`P`(.``()+@`P"4X&4!@.#J38+@J%">Y6PA)N`*("+@`@"0X&HAH.$#
M4)7@L*">Y090E>!L82+@!&`FX.0-@.`&4)7@`V":X&QAAN"XH)[EX,V%X&11
M(N``4"7@!6"6X&`!H.$#4)K@`E"5X,"@GN7L+8;@9&$@X`Q@)N`&4)7@`V":
MX&1AAN#(H)[E;$$@X`)`).#B787@!&"6X&(AH.$#0)K@``"4X-"@GN5L02+@
M!4`DX`1`D.`#`)K@Y6V&X-B@GN5L`8#@9<$BX`;`+.#F383@#`"0X&9AH.$#
MP)K@`B"<X."@GN5EP2;@!,`LX`S`DN`#()K@Y`V`X.B@GN5E(8+@9%$FX`!0
M)>#@S8S@!2"2X&`!H.$#4)K@!E"5X/B@GN7P8)[E9.$@X`S@+N#L+8+@#N"5
MX.)=CN`#8);@;.$@X&1!AN`"X"[@#N"4X&(AH.$#0)K@`$"4X!AAG>5L`2+@
M!0`@X.7MCN```)3@`V"6X.Y-@.!LP8;@90$BX"!AG>4.`"#@``"<X&[AH.$#
M8);@`B"6X&7!+N`H89WE!,`LX.0-@.`,P)+@`R"6X&4A@N`P89WEX%V,X&3!
M+N``P"S@#,"2X&`!H.$#8);@Y2V,X`[@EN!DP2#@.&&=Y07`+.`,P)[@`^"6
MX&3ACN!`89WE94$@X`)`).#BS8S@!.">X&(AH.$#8);@``"6X&5!(N!(89WE
M#$`DX.SMCN!0H9WE!$"0X`,`EN#L-9_E;&$BX&4!@.`.8";@;E&@X>Y-A.`&
M8)#@;.&%X0,`FN`"`)#@6*&=Y>0MAN`$X`[@;&$%X`;@CN$.X)#@`Z":X&0!
MA>%D807@;,&*X`(``.!@H9WE!@"`X>+MCN`,`)#@8B&@X0/`FN`%P)S@9%&"
MX61A`N!HH9WE#E`%X`90A>'N#8#@#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@
M<*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@`L"<X.4MA.!N08#A;F$`X'BAG>4%
M0`3@!D"$X0Q`E.`#H)K@9<&`X65A`.!NX8K@`L`,X("AG>4&P(SAXDV$X`[@
MG.!B(:#A`\":X`#`G.#D#8[@9>&"X65A`N"(H9WE!.`.X`;@CN$,X)[@`Z":
MX&3!@N%D80+@95&*X`#`#."0H9WE!L",X>#MCN`%4)S@8`&@X0/`FN`"P)S@
M[BV%X&11@.%D80#@F*&=Y0Y0!>`&4(7A#%"5X`.@FN!NP8#A;F$`X&1!BN`"
MP`S@H*&=Y0;`C.'B787@!$"<X&(AH.$#P)K@`,"<X.4-A.!N08+A;F$"X*BA
MG>4%0`3@!D"$X0Q`E.`#H)K@9<&"X65A`N!NX8K@`,`,X+"AG>4&P(SAX$V$
MX`[@G.!@`:#A`\":X`+`G.#D+8[@9>&`X65A`."XH9WE!.`.X`;@CN$,X)[@
M`Z":X&3!@.%D80#@95&*X`+`#.#`H9WE!L",X>+MCN`%4)S@8B&@X0/`FN``
MP)S@[@V%X&11@N'(H9WE9&$"X`Y0!>`&4(7A#%"5X`.@FN!NP8+A;F$"X&1!
MBN``P`S@T*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@`&"@XP+`G.#E+83@;D&`
MX05`!.`$8('E#&"!Y11@@>4<8('E;F$`X-BAG>4&0(3A#$"4X&7!@.$#H)K@
M96$`X`+`#.!NX8K@!L",X>"AG>7B383@#L"<X&(AH.'D[8S@`Z":X&7!@N%E
M80+@``":X`3`#.#HH9WE!L",X0#`G.`#H)K@9`&"X>@RG^5D80+@95&*X`X`
M`.#PH9WE!@"`X>[-C.`%`)#@;N&@X0-0FN`"4)7@^&&=Y60A+N`,("+@[`V`
MX`(@E>`#8);@X%V"X&1!AN!L(2[@`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@
M"&*=Y6SA(.`%X"[@#N"4X`-`EN#E+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,
MP)3@8B&@X0-`EN``0)3@&&*=Y64!(N`.`"#@[LV,X```E.`#0);@94&$X"!B
MG>7L78#@;@$BX`P`(.```)3@;,&@X0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`
MX`(@E.`#8);@X$V"X&[AAN!E(2S@,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@
M.&*=Y67!(.`$P"S@Y"V"X`S`GN`#X);@9>&.X$!BG>7B78S@9,$@X`+`+.`,
MP)[@8B&@X0/@EN``X)[@2&*=Y60!(N`%`"#@Y<V,X```GN`#X);@9.&.X%!B
MG>7L38#@90$BX`P`(.```)[@;,&@X0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`
MX`(@GN`#X);@9>&.X&!BG>7@78+@9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@
M:&*=Y63!(.`%P"S@Y2V"X`S`GN`#X);@9.&.X'!BG>7B38S@9<$@X`+`+.`,
MP)[@8B&@X0/@EN``X)[@>&*=Y64!(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A
M(N"`4IWE#&`FX.P-@.`&X)[@;,&@X0-0E>`"()7@9&$LX(A2G>4`8";@!B"2
MX`,PE>#@[8[@8)&)X`@PD^!@`2S@#@`@X&0Q@^``,)/@[BV"X.(]@^!N<8?@
M"R"2X"``D>48D('E$'"!Y0`P@>4((('E4""?Y3@PG^4"((_@`,"<X`!@H.,@
MP('E)&"!Y0,PDN<`()/EE#*=Y0(@,^``,*#C`0``&J??C>+PC[WHS_+_Z\1C
M```$`0``F7F"6J'KV6[<O!N/UL%BRJ!7```!RJ#C<$`MZ0S`3>#P#XSE@`"@
MX^;R_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X((#E^$#`X4!0C^+00,7A
M\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`H.,`4*#C^$+`X?!#P.%P
M@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#``````'*
MH./P1RWI#,!-X.`/C.4H,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@`%"@
MX3`@D.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@
MH!ZAX'@`E>4HP(7E``!0XSB`A0(P,(7E-!"%Y18``!H_`%;C)@``VD!@1N(F
MDZ#A`7")X@=SA.`$$*#A0""@XP@`H.%G\O_K0$"$X@4`H.&)_/_K!P!4X?;_
M_QH)G6G@"6.&X`8@H.$'$*#A"`"@X5SR_^MX8(7E\(>]Z$!P8.(&`%?A!G"@
MH3B`A>(``(C@!R"@X000H.%2\O_K>#"5Y0,PA^!``%/C>#"%Y?"'O1@%`*#A
M!V!&X`=`A.!N_/_KUO__Z@1PH.'E___J`<J@X_!!+>D,P$W@Z`^,Y2@PD>4!
M0*#A8R@CX#`0D>4B)*#A_RS"XV-T(N!A*"'@HS&@X2(DH.$_,`/B_RS"XV%D
M(N`!$(/B.("$XG\@X.,X`%'C`%"@X0,@R.<]``#:0"!AX@$`B.``$*#CC?+_
MZP0`H.%-_/_K.""@XP`0H.,(`*#AA_+_ZP0`H.%P8(3E='"$Y47\_^L#,-3E
M`##%Y;(PU.$!,,7E`#"4Y00`H.$C-*#A`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z
M,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4',,7E$S#4Y0@PQ>6R,=3A"3#%Y1`P
ME.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PPQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%
MY1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%Y2`PE.4C-*#A$C#%Y2`PE.43,,7E
M\$&]Z.WQ_^H!`(C@."!AX@`0H.-/\O_KQO__Z@````````````````\*X.,?
M\$#B"#"?Y0,PC^``,)/E]_'_ZD!5```(0"WI"("]Z`$``@`^````00````P`
M``!!````$0```$$````G````00```#8```!!`````P```$$````&````00``
M`!4```!!````#P```$$````.````00```"8```!!````$P```$$````I````
M00````(```!!````&0```$$````*````00````L```!!```````````````E
M<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE
M`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``
M+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%
M0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/
M0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.`````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,
M1%],24)205)97U!!5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A
M<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S
M(&9A:6QE9"`H97)R;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y
M("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U
M<B!O<&5R871I;VXI"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@
M<F5A9```)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M
M<"TE=2TE=25S`````!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D52
M4TE/3@`````Q+C`V,0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C
M=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````+64``"TM``!54T52````
M`%5315).04U%`````%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O
M=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U
M;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H
M)%!!4E]-04=)0RP@)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I
M>F4I.PI"14=)3B!["B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%
M7V]F9G-E=%]S:7IE(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S
M:7IE(#T@-#`["B102UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@
M9FEN9%]P87)?;6%G:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ
M92`](#8T("H@,3`R-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY
M("1P;W,@/2`H)'-I>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@
M("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ
M90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D
M("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD[
M"FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I
M('L*<F5T=7)N("1P;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]
M"G)E='5R;B`M,3L*?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE+"`E36]D=6QE0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIM>2`D9FEL96YA;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\
M/"(N+BXB.PIX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@
M)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R
M96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL
M96YA;64G"BXN+@IC;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64[
M"FUY("1C;60@/2`B)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES
M=&5M*"1C;60I.PIO=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S
M('1O('!E<F9O<FT@8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.
M('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA
M;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<
M)'!R;V=N86UE(#T@(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO
M=71S*'%Q6UPD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*
M;7D@*"1S=&%R=%]P;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)
M0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO
M<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@
M<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A
M(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G
M:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG
M("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'
M24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I
M8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?
M<VEZ92`M(&QE;F=T:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@
M;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D
M8G5F(&YE(")<,$-,14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U
M;F0B*3L*;&%S="!-04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U
M9B(@9F]U;F1=*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S
M971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE
M.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E
M="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`[
M"B1S=&%R=%]O9E]&24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I
M<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U
M=',H<7%;56YP86-K:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R
M8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@
M.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_
M.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?
M1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT
M*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I
M;&5N86UE(#T@7W-A=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE
M.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^
M("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E
M<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0[
M"GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@
M0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN
M9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN
M9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U
M;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#
M3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]
M($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T
M96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN
M9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L
M<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M
M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*
M;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B
M0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U
M;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q
M=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME
M>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M
M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@
M/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*
M9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI
M>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65]
M.PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II
M<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M
M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A
M<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D[
M"F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A21553
M12!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@
M;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*
M;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L
M;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I
M9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G
M*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@
M0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A
M9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!
M24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@
M>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2![
M"F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T
M($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@
M)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]
M"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF
M("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG
M*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E
M;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D
M<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG
M="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ
M1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!
M6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@
M(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M
M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A
M(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE
M=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D
M("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q
M6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E
M860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F
M:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*
M?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*
M)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H
M*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A
M;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*
M<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R
M=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968[
M"B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P
M;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@
M*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE
M<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U
M;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C
M:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP
M?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY
M("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA
M<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S
M(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H
M;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F
M:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M
M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD
M?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF
M("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D
M<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D
M<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L
M("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT
M('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE
M?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L
M:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S
M(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM
M>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL
M92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@
M)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^
M+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT
M+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M
M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*
M<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R
M*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E
M9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N
M86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A
M<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII
M9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ
M4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F
M:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I
M9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C
M:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H
M+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG
M+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ
M6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL
M96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=
M.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*
M;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M
M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@
M*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T
M('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E
M<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB
M97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M
M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[
M87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]
M("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6
M>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE
M("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U
M=',H<7%;4VMI<'!I;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D
M>2!E>&ES=',@870@(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;
M17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=
M*3L**"1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]
M/2!!<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R
M86-T:6YG('II<"!M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U
M-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE
M<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U
M;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@
M72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@
M6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@
M0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"
M87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ
M0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E
M($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S
M*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E
M<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D
M97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@
M=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E
M($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q
M=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@
M6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4[
M"G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E
M<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M<WES>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!
M4E]#3$5!3GTI('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*
M;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@
M/2!F:6YD7W!A<E]M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G
M:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(
M12(I.PII9B`H)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I
M8U]P;W,*+2`D1DE,15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I
M"BT@)&-A8VAE7VYA;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H
M95]N86UE7W-I>F4["B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C
M86-H92TD8G5F(CL*?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I
M('L*)&-A8VAE7V1I<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@
M,3L*?0HD<W1M<&1I<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*
M;7D@*"1N86UE+"`D8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA
M;64@/2`B)'!A<E]T96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I
M('L*;7D@)'1E;7!N86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P
M96X@)&9H+"`G/CIR87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O
M;G1E;G1S*0HF)B`H8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN
M9R`B)'1E;7!N86UE(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF
M(&1E9FEN960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@
M;W(@=6YL:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS
M=6(@7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.
M04U%?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O
M9VYA;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P
M<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB
M*2!["B1P<F]G;F%M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E
M86-H(&UY("1D:7(@*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6
M>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D
M9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI
M;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M921S>7-[7V5X97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI
M;7TD<')O9VYA;64D<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[
M7V1E;&EM?21P<F]G;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P
M(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]
M("(N)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN
M960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@
M)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC
M:&]M<"@D<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D
M96QI;7U<12DO)'!W9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE
M=&4@)$5.5GLB4$%27R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%
M04X@1$5"54<@+RD@>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?2!I9B!E>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF
M("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]
M"GT*<W5B(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2![
M"G!R:6YT("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*
M?0I]"G-U8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L
M(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA
M<F-H;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV
M96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*
M<F5Q=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI0
M05(M/FEM<&]R="A`<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O
M<&5N('!E<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@
M9&ER96-T;W)Y7&Y="G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M
M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI
M7"DO*3L*9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`[
M"GT*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ
M.PI?7T5.1%]?"@!P97)L>'-I+F,`````0T%#2$4``#X```!!````#````$$`
M```1````00```"<```!!````-@```$$````#````00````8```!!````%0``
M`$$````/````00````X```!!````)@```$$````3````00```"D```!!````
M`@```$$````9````00````H```!!````"P```$$``````````````+B*_W\!
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#D&```?!@```$````J`P```0```#H#```!````1`,`
M``P```"\$0``#0```,Q*```9````O)T``!L````$````&@```,"=```<````
M!````/7^_V^L`0``!0```"@)```&````F`(```H```"Y!```"P```!`````5
M``````````,```#,G@```@```.`!```4````$0```!<```#<#P``$0````0/
M```2````V````!,````(````'@````@```#[__]O`0``"/[__V^T#@``____
M;P(```#P__]OX@T``/K__V\.````````````````````````````````````
M`````````````````````,2=`````````````,@1``#($0``R!$``,@1``#(
M$0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1
M``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$`
M`,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``
MR!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#(
M$0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$`````
M``````````````````````````````````````````````````"P%```````
M``````````````````2@```*4$%2+G!M"@````"L3@``Q$L```````"$3```
MB$P``*!.``#,2P``J$X```````",3@``E$X```````"T3@``1T-#.B`H1&5B
M:6%N(#$S+C(N,"TQ-BXQ*2`Q,RXR+C``02H```!A96%B:0`!(`````4U5$4`
M!@0(`0D!$@03`10!%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T
M92YG;G4N8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y
M;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y
M;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI
M9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC
M`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T=')I8G5T97,`````
M``````````````````````````````````````````````````````L````!
M`````@```%0!``!4`0``$P```````````````0`````````3````!P````(`
M``!H`0``:`$``"0```````````````0`````````)@````<````"````C`$`
M`(P!```@```````````````$`````````#0```#V__]O`@```*P!``"L`0``
M[`````4`````````!`````0````^````"P````(```"8`@``F`(``)`&```&
M`````P````0````0````1@````,````"````*`D``"@)``"Y!```````````
M```!`````````$X```#___]O`@```.(-``#B#0``T@````4``````````@``
M``(```!;````_O__;P(```"T#@``M`X``%`````&`````@````0`````````
M:@````D````"````!`\```0/``#8````!0`````````$````"````',````)
M````0@```-P/``#<#P``X`$```4````5````!`````@```!\`````0````8`
M``"\$0``O!$```P```````````````0`````````=P````$````&````R!$`
M`,@1``#D`@`````````````$````!````((````!````!@```+`4``"P%```
M'#8`````````````$`````````"(`````0````8```#,2@``S$H```@`````
M``````````0`````````C@````$````"````U$H``-1*``#T00``````````
M```$`````````)8````!``!P@@```,B,``#(C```"`````T`````````!```
M``````"A`````0````(```#0C```T(P```0```````````````0`````````
MJP````X````#````O)T``+R-```$```````````````$````!````+<````/
M`````P```,"=``#`C0``!```````````````!`````0```##````!@````,`
M``#$G0``Q(T```@!```&``````````0````(````S`````$````#````S)X`
M`,R.```T`0`````````````$````!````-$````!`````P````"@````D```
M2```````````````!`````````#7````"`````,```!(H```2)```!0`````
M``````````0`````````W`````$````P`````````$B0```A````````````
M```!`````0```.4````#``!P``````````!ID```*P```````````````0``
M```````!`````P``````````````E)```/4```````````````$`````````
